const config = require('../config/keys');
const { vault } = require('../utils');
const { instance: dockerClient } = require('../federated/flDocker');

module.exports = {
  pullFederatedImage: async (federatedJobImage) => {
    //Ensure vault is healty (needed later)
    try {
      await vault.healthStatus();
    } catch (error) {
      throw new Error(`Error with vault. Check if it is unsealed: ${error}`);
    }

    // Pull the federated learning image
    try {
      const harborAuthOptions = {
        email: config.harborEmail,
        username: config.harborUsername,
        password: config.harborPassword,
      };

      dockerClient.pull(
        federatedJobImage,
        { authconfig: harborAuthOptions },
        (err, stream) => {
          if (err) {
            throw new Error(`Error pulling federated learning image: ${err}`);
          }

          dockerClient.modem.followProgress(stream, onFinished, onProgress);

          function onFinished(err, output) {
            if (err) {
              console.error(
                `Something went wrong while pulling federated learning image: ${err}`
              );
            } else {
              console.log(
                'Pulling federated learning image completed successfully.'
              );
            }
          }

          // Show pull progress in console
          function onProgress(event) {
            console.log(event);
          }
        }
      );
    } catch (error) {
      throw new Error(`Error pulling federated learning image: ${error}`);
    }
  },
};
