const mongoose = require('mongoose');

const agentSchema = new mongoose.Schema(
  {
    name: {
      type: String,
      required: true,
      unique: true,
      set: (value) => value.toLowerCase().replace(/\s+/g, '-'),
    },
    hostSource: {
      type: String,
      required: true,
    },
    containerDestination: {
      type: String,
      required: true,
    },
    active: { type: Boolean, default: true },
    type: {
      type: String,
      enum: ['incremental', 'federated'],
      required: true,
    },
    privacySetting: {
      type: String,
      enum: ['inspect-results', 'no-result-inspection'],
      required: true,
    },
    trainIds: [{ type: String, required: true }],
    executionParameters: { type: Map, of: String },
    inspectionBypass: { type: Boolean, default: false },
    environmentVariables: [
      {
        name: { type: String, required: true },
        type: { type: String, required: true },
        value: { type: String, required: true },
      },
    ],
  },
  {
    timestamps: true,
  }
);

module.exports = mongoose.model('Agent', agentSchema);
