import * as React from 'react';
import { useField } from 'formik';
import IconButton from '@mui/material/IconButton';
import TextField from '@mui/material/TextField';
import InputAdornment from '@mui/material/InputAdornment';
import Visibility from '@mui/icons-material/Visibility';
import VisibilityOff from '@mui/icons-material/VisibilityOff';

const TextFieldWrapper = ({ name, ...otherProps }) => {
  const [field, meta] = useField(name);
  const [showPassword, setShowPassword] = React.useState(false);

  const textfieldConfig = {
    fullWidth: true,
    size: 'small',
    variant: 'outlined',
    ...field,
    ...otherProps,
    value: field.value || '', // This check is to avoid undefined values when adding custom envs
  };

  if (meta && meta.touched && meta.error) {
    textfieldConfig.error = true;
    textfieldConfig.helperText = meta.error;
  }

  const handleClickShowPassword = () => setShowPassword((show) => !show);

  const handleMouseDownPassword = (event) => {
    event.preventDefault();
  };

  if (textfieldConfig.type === 'password') {
    textfieldConfig.InputProps = {
      endAdornment: (
        <InputAdornment position="end">
          <IconButton
            aria-label="toggle password visibility"
            onClick={handleClickShowPassword}
            onMouseDown={handleMouseDownPassword}
            edge="end"
          >
            {showPassword ? <VisibilityOff /> : <Visibility />}
          </IconButton>
        </InputAdornment>
      ),
    };
  }

  return (
    <TextField
      {...textfieldConfig}
      type={showPassword ? 'text' : textfieldConfig.type}
    />
  );
};

export default TextFieldWrapper;
