import Alert from '@mui/material/Alert';
import Typography from '@mui/material/Typography';
import TextField from '@mui/material/TextField';
import MenuItem from '@mui/material/MenuItem';
import Stack from '@mui/material/Stack';
import InfoIcon from '@mui/icons-material/InfoOutlined';

import { HtmlTooltip } from './Tooltip';
import { privacySettingOptions } from '../constants';

export default function PrivacySetting({
  inspectResults,
  privacySetting,
  onChangePrivacy,
  disabled,
}) {
  return (
    <Stack sx={{ my: 2 }} spacing={2}>
      <Stack direction="row" spacing={1} alignItems="center">
        <Typography variant="h6" sx={{ fontWeight: 'bold' }}>
          Privacy Settings
        </Typography>
        <HtmlTooltip
          placement="right"
          title="Control how data will leave your station"
        >
          <InfoIcon />
        </HtmlTooltip>
      </Stack>
      <Alert
        severity={inspectResults ? 'info' : 'warning'}
        sx={{ fontWeight: '500' }}
      >
        {inspectResults ? (
          <>
            With this setting, the station admin has <b>full control</b> over
            which data is leaving the station. After every learning round, the
            admin can view the data that will be transmitted and approve the
            transmission.
          </>
        ) : (
          <>
            With this setting, the station will <b>automatically transmit</b>{' '}
            the data after every learning round. The station admin can inspect
            the data <b>after transmission.</b>
          </>
        )}
      </Alert>
      <TextField
        select
        fullWidth
        size="small"
        label="Setting"
        value={privacySetting}
        disabled={disabled}
        onChange={onChangePrivacy}
      >
        <MenuItem value={privacySettingOptions.INSPECT_RESULTS}>
          Require data inspection before transmission (default)
        </MenuItem>
        <MenuItem value={privacySettingOptions.NO_RESULT_INSPECTION}>
          Transmit data without inspection
        </MenuItem>
      </TextField>
    </Stack>
  );
}
